akhdefo_functions.Akhdefo_resample — Akhdefo software documentation

# akhdefo_functions.Akhdefo_resample

akhdefo_functions.Akhdefo_resample(input_raster='', output_raster='', xres=3.125, yres=3.125, SavFig=False, convert_units=False)

  This program performs raster resampling for rasters

  ## Parameters

  input_rasterstr

    path to input raster

  output_rasterstr

    path to output raster

  xresfloat

    horizontal resolution

  yresfloat

    vertical resolution

  SavFigbool

    True to save output plot False to ignore exporting plot

  convert_unitsbool

    if True converts raster value units from m to mm

  ## Returns

  Raster geotif